@@ -3,8 +3,8 @@
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 # In applying this licence, ECMWF does not waive the privileges and immunities
-# granted to it by virtue of its status as an intergovernmental organisation nor
-# does it submit to any jurisdiction.
+# granted to it by virtue of its status as an intergovernmental organisation
+# nor does it submit to any jurisdiction.
 #
 
 # The code is copied from skinnywms, and we should combile later
@@ -132,27 +132,13 @@ class NetCDFField:
 
     def plot_map(self, driver):
 
-        dimensions = ["%s:%s" % (s.name, s.index) for s in self.slices]
-
-        if dimensions:
-            params = dict(
-                netcdf_filename=self.path,
-                netcdf_value_variable=self.variable,
-                netcdf_dimension_setting=dimensions,
-                netcdf_dimension_setting_method="index",
-            )
-        else:
-            params = dict(
-                netcdf_filename=self.path, netcdf_value_variable=self.variable
-            )
-
-        # params['netcdf_field_automatic_scaling'] = 'off'
+        dimensions = dict((s.name, s.index) for s in self.slices)
 
         driver.bounding_box(
             north=self.north, south=self.south, west=self.west, east=self.east
         )
 
-        driver.plot_netcdf(params)
+        driver.plot_netcdf(self.path, self.variable, dimensions)
 
     def __repr__(self):
         return "NetCDFField[%r,%r]" % (self.variable, self.slices)
